@@ -25,8 +25,8 @@
 #include <ctype.h>
 #include <locale.h>
 #include <libintl.h>
-#include <malloc.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
 
